/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package de.crowdcode.kissmda.core.jdt;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.jdt.core.dom.PrimitiveType;
import org.eclipse.jdt.core.dom.PrimitiveType.Code;

/**
 * Data Type Helper class for Java language with JDT.
 * 
 * @author Lofi Dewanto
 * @since 1.0.0
 * @version 1.0.0
 */
public class DataTypeUtils {

	private static Map<String, Code> primitiveTypeCodes = null;

	private static Map<String, String> javaTypes = null;

	public Map<String, Code> getPrimitiveTypeCodes() {
		if (primitiveTypeCodes == null) {
			primitiveTypeCodes = new HashMap<String, Code>();
			primitiveTypeCodes.put("integer", PrimitiveType.INT);
			primitiveTypeCodes.put("short", PrimitiveType.SHORT);
			primitiveTypeCodes.put("double", PrimitiveType.DOUBLE);
			primitiveTypeCodes.put("long", PrimitiveType.LONG);
			primitiveTypeCodes.put("boolean", PrimitiveType.BOOLEAN);
			primitiveTypeCodes.put("byte", PrimitiveType.BYTE);
			primitiveTypeCodes.put("character", PrimitiveType.CHAR);
			primitiveTypeCodes.put("void", PrimitiveType.VOID);
		}

		return primitiveTypeCodes;
	}

	public Map<String, String> getJavaTypes() {
		if (javaTypes == null) {
			javaTypes = new HashMap<String, String>();
			javaTypes.put("integer", "Integer");
			javaTypes.put("short", "Short");
			javaTypes.put("double", "Double");
			javaTypes.put("long", "Long");
			javaTypes.put("boolean", "Boolean");
			javaTypes.put("string", "String");
			javaTypes.put("date", "java.util.Date");
		}

		return javaTypes;
	}

	public boolean isPrimitiveType(String typeName) {
		Map<String, Code> primitiveTypeCodes = getPrimitiveTypeCodes();
		Code primitiveTypeCode = primitiveTypeCodes.get(typeName);
		if (primitiveTypeCode != null) {
			return true;
		} else {
			return false;
		}
	}
}
